from pathlib import Path
import os


RESOURCE_DIRECTORY = str(Path(__file__).resolve().parent)

DB_FILEPATH = os.path.join(RESOURCE_DIRECTORY, "ewoks_events.db")

if os.path.exists(DB_FILEPATH):
    os.remove(DB_FILEPATH)

EWOKS = {
    "handlers": [
        {
            "class": "ewokscore.events.handlers.Sqlite3EwoksEventHandler",
            "arguments": [{"name": "uri", "value": f"file:{DB_FILEPATH}"}],
        }
    ]
}



import setuptools
import distutils.command.build


class BuildCommand(distutils.command.build.build):
    def initialize_options(self):
        distutils.command.build.build.initialize_options(self)
        self.build_base = "pybuild"


if __name__ == "__main__":
    setuptools.setup(cmdclass={"build": BuildCommand})



import os


def get_static_root() -> str:
    return os.path.join(os.path.dirname(__file__), "static")


def get_test_config() -> str:
    return os.path.join(os.path.dirname(__file__), "tests", "resources", "config.py")
